@@ -359,6 +359,8 @@ class LoadMaster(HttpClient):
                     subvs.populate_default_attributes(vs)
                     #subvs_api_entries = get_dict_entry_as_list("SubVS", data)
                     subvs_api_entries = service.get("SubVS", [])
+                    if not isinstance(subvs_api_entries, list):
+                        subvs_api_entries = [subvs_api_entries]
                     for subvs_api in subvs_api_entries:
                         # add the "Rs" part of the subvs to the subvs instance
                         if subvs_api["VSIndex"] == subvs.index:
