@@ -175,3 +175,11 @@ class DownloadUserCertFailed(KempTechApiException):
         msg = ("Failed to download user cert. Could not reach LoadMaster {}."
                .format(ip_address))
         super(DownloadUserCertFailed, self).__init__(msg, code=code)
+
+
+class UserAlreadyExistsException(KempTechApiException):
+    def __init__(self, user, ip_address, code=None):
+        msg = ("User '{}' already exists on LoadMaster {}."
+               .format(user, ip_address))
+        super(UserAlreadyExistsException, self).__init__(msg, code=code,
+                                                         is_xml_msg=False)
