@@ -63,6 +63,11 @@ class UseTlsAdapter(HTTPAdapter):
 
 
 def get_sub_vs_list_from_data(response_data):
+    """Get Sub VS IDs and the "Rs" data portion of the Sub VSs as a tuple
+
+    :param response_data: Data portion of LM API response
+    :return: Tuple of list of sub VS IDs and a dict of full RS sub VS data
+    """
     subvs_entries = []
     full_data = {}
     for key, value in response_data.items():
@@ -79,3 +84,11 @@ def get_sub_vs_list_from_data(response_data):
 
 def get_api_bool_string(api_bool):
     return 'y' if api_bool else 'n'
+
+
+def get_dict_entry_as_list(key, data):
+    """Returns an entry from a dict as a list"""
+    value = data.get(key, [])
+    if not isinstance(value, list):
+        value = [value]
+    return value
